My machine has port 12345 taken and that "socket.error: [Errno 48] Address 
already in use" and the test failure has been bugging me for too long already. 
Let's get a random available port instead.

http://reviews.llvm.org/D5221

Files:
  test/functionalities/connect_remote/EchoServer.py
  test/functionalities/connect_remote/TestConnectRemote.py
Index: test/functionalities/connect_remote/EchoServer.py
===================================================================
--- test/functionalities/connect_remote/EchoServer.py
+++ test/functionalities/connect_remote/EchoServer.py
@@ -8,10 +8,11 @@
 import socket
 
 HOST = 'localhost'        # Symbolic name meaning local interfaces
-PORT = 12345              # Arbitrary non-privileged port
+PORT = 0                  # Let the system give us a random free port
 s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 s.bind((HOST, PORT))
-print '\nListening on %s:%d' % (HOST, PORT)
+PORT = s.getsockname()[1]
+print 'Listening on %s:%d' % (HOST, PORT)
 s.listen(1)
 conn, addr = s.accept()
 print 'Connected by', addr
Index: test/functionalities/connect_remote/TestConnectRemote.py
===================================================================
--- test/functionalities/connect_remote/TestConnectRemote.py
+++ test/functionalities/connect_remote/TestConnectRemote.py
@@ -5,6 +5,7 @@
 import os
 import unittest2
 import lldb
+import re
 from lldbtest import *
 
 class ConnectRemoteTestCase(TestBase):
@@ -12,7 +13,7 @@
     mydir = TestBase.compute_mydir(__file__)
 
     def test_connect_remote(self):
         """Test "process connect connect:://localhost:12345"."""
 
         import pexpect
         # First, we'll start a fake debugserver (a simple echo server).
@@ -28,10 +29,13 @@
         self.addTearDownHook(shutdown_fakeserver)
 
         # Wait until we receive the server ready message before continuing.
-        fakeserver.expect_exact('Listening on localhost:12345')
+        line = fakeserver.readline()
+        self.assertTrue(line.startswith("Listening on localhost:"))
+        port = int(re.match('Listening on localhost:([0-9]+)', line).group(1))
+        self.assertTrue(port > 0)
 
         # Connect to the fake server....
-        self.runCmd("process connect -p gdb-remote connect://localhost:12345")
+        self.runCmd("process connect -p gdb-remote connect://localhost:" + str(port))
 
 
 if __name__ == '__main__':
@@ -12,7 +13,7 @@
 
     def test_connect_remote(self):
-        """Test "process connect connect:://localhost:12345"."""
+        """Test "process connect connect:://localhost:[port]"."""
 
         import pexpect
_______________________________________________
lldb-commits mailing list
[email protected]
http://lists.cs.uiuc.edu/mailman/listinfo/lldb-commits

Reply via email to